#
# spec file for package python-astropy-helpers
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without tests

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-astropy-helpers
Version:        2.0.2
Release:        lp151.2.2
Summary:        Utilities for building and installing Astropy
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            http://astropy.org
Source:         https://files.pythonhosted.org/packages/source/a/astropy-helpers/astropy-helpers-%{version}.tar.gz
Source100:      python-astropy-helpers-rpmlintrc
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpydoc}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Sphinx
Requires:       python-numpy
Requires:       python-numpydoc
BuildArch:      noarch
%python_subpackages

%description
This project provides a Python package, astropy_helpers, which includes
many build, installation, and documentation-related tools used by the Astropy
project, but packaged separately for use by other projects that wish to
leverage this work.  The motivation behind this package and details of its
implementation are in the accepted Astropy Proposal for Enhancement (APE) 4:
https://github.com/astropy/astropy-APEs/blob/master/APE4.rst

astropy_helpers includes a special "bootstrap" module called
ah_bootstrap.py which is intended to be used by a project's setup.py in
order to ensure that the astropy_helpers package is available for
build/installation.  This is similar to the ez_setup.py module that is
shipped with some projects to bootstrap setuptools.

%prep
%setup -q -n astropy-helpers-%{version}

%build
%python_build

%install
%python_install
%{python_expand %fdupes %{buildroot}%{$python_sitelib}
$python -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/astropy_helpers
$python -O -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/astropy_helpers
%fdupes %{buildroot}%{$python_sitelib}
}

%files %{python_files}
%defattr(-,root,root,-)
%doc README.rst LICENSE.rst CHANGES.rst
%{python_sitelib}/*

%changelog
* Wed Jan 10 2018 toddrme2178@gmail.com
- Update to version 2.0.2
  * Added new helper function add_openmp_flags_if_available that can add
    OpenMP compilation flags to a C/Cython extension if needed. [#346]
  * Update numpydoc to v0.7. [#343]
  * The function ``get_git_devstr`` now returns ``'0'`` instead of ``None`` when
    no git repository is present. This allows generation of development version
    strings that are in a format that ``setuptools`` expects (e.g. "1.1.3.dev0"
    instead of "1.1.3.dev"). [#330]
  * It is now possible to override generated timestamps to make builds
    reproducible by setting the ``SOURCE_DATE_EPOCH`` environment variable [#341]
  * Mark Sphinx extensions as parallel-safe. [#344]
  * Switch to using mathjax instead of imgmath for local builds. [#342]
  * Deprecate ``exclude`` parameter of various functions in setup_helpers since
    it could not work as intended. Add new function ``add_exclude_packages`` to
    provide intended behavior. [#331]
  * Allow custom Sphinx doctest extension to recognize and process standard
    doctest directives ``testsetup`` and ``doctest``. [#335]
- Update to version 2.0.1
  * Fix compatibility with Sphinx <1.5. [#326]
- Update to version 2.0
  * Add support for package that lies in a subdirectory. [#249]
  * Removing ``compat.subprocess``. [#298]
  * Python 3.3 is no longer supported. [#300]
  * The 'automodapi' Sphinx extension (and associated dependencies) has now
    been moved to a standalone package which can be found at
    https://github.com/astropy/sphinx-automodapi - this is now bundled in
    astropy-helpers under astropy_helpers.extern.automodapi for
    convenience. Version shipped with astropy-helpers is v0.6.
    [#278, #303, #309, #323]
  * The ``numpydoc`` Sphinx extension has now been moved to
    ``astropy_helpers.extern``. [#278]
  * Fix ``build_docs`` error catching, so it doesn't hide Sphinx errors. [#292]
  * Fix compatibility with Sphinx 1.6. [#318]
  * Updating ez_setup.py to the last version before it's removal. [#321]
* Wed May 17 2017 toddrme2178@gmail.com
- Implement single-spec version
- Fix source URL.
- Update to version 1.3.1
  - Fixed the missing button to hide output in documentation code
    blocks. [#287]
  - Fixed bug when ``build_docs`` when running with the clean (-l) option. [#289]
  - Add alternative location for various intersphinx inventories to fall back
    to. [#293]
- Update to version 1.3
  - ``build_sphinx`` has been deprecated in favor of the ``build_docs`` command.
    [#246]
  - Force the use of Cython's old ``build_ext`` command. A new ``build_ext``
    command was added in Cython 0.25, but it does not work with astropy-helpers
    currently.  [#261]
* Wed Jul  6 2016 asterios.dramis@gmail.com
- Update to version 1.2:
  * Added sphinx configuration value
    ``automodsumm_inherited_members``. If ``True`` this will
    include members that are inherited from a base class in the
    generated API docs. Defaults to ``False`` which matches the
    previous behavior. [#215]
  * Fixed ``build_sphinx`` to recognize builds that succeeded but
    have output *after* the "build succeeded." statement. This only
    applies when ``--warnings-returncode`` is  given (which is
    primarily relevant for Travis documentation builds).  [#223]
  * Fixed ``build_sphinx`` the sphinx extensions to not output a
    spurious warning for sphinx versions > 1.4. [#229]
  * Add Python version dependent local sphinx inventories that
    contain otherwise missing references. [#216]
  * ``astropy_helpers`` now require Sphinx 1.3 or later. [#226]
  From version 1.1.2:
  * The CSS for the sphinx documentation was altered to prevent
    some text overflow problems. [#217]
- Added new build/runtime requirement python-Sphinx.
- Added python-astropy-helpers-rpmlintrc for
  "devel-file-in-non-devel-package" rpmlint error (compiler.c is
  needed by the package).
* Tue Feb  2 2016 toddrme2178@gmail.com
- Initial version
